@@ -63,7 +63,7 @@ class Task(Stage):
 
     @property
     def id(self):
-        return self.name
+        return self.name if self.name else self._function.key
 
     @classmethod
     def to_yaml(cls, dumper, data):
@@ -80,6 +80,10 @@ class Iterator(YamlOrderedDict):
         self.auto_catch = auto_catch
         self.auto_fallback = auto_fallback
 
+    @property
+    def id(self):
+        return self.map_name
+
     @classmethod
     def to_yaml(cls, dumper, data):
         data["StartAt"] = list(data.States.keys())[0]
